﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Data;

namespace UsingGroupDescriptors
{
	public partial class MainPage : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;
 
		protected void NotifyPropertyChanged(string propertyName)
		{
			var propertyChanged = PropertyChanged;
 
			if ((propertyChanged != null))
			{
				propertyChanged(
					this, new PropertyChangedEventArgs(propertyName));
			}
		}
 
		private PagedCollectionView listUsers;
 
		public PagedCollectionView ListUsers
		{
			get
			{
				return listUsers;
			}
 
			set
			{
				listUsers = value;
 
				NotifyPropertyChanged("ListUsers");
			}
		}

		public MainPage()
		{
			InitializeComponent();
			Loaded+=MainPage_Loaded;
		}
 
		private void MainPage_Loaded(object sender, RoutedEventArgs e)
		{
			var user1 = new User("Nguyen", "Cuong");
 
			var user2 = new User("Nguyen", "Tu");
 
			var users = new ObservableCollection<User>{ user1, user2 };
 
			ListUsers = new PagedCollectionView(users);
 
			lstView.ItemsSource = ListUsers;
		}
	}

	public class User :INotifyPropertyChanged
	{
		private string firstName;
		private string lastName;

		public string FirstName
		{
			get
			{
				return this.firstName;
			}
			set
			{
				if (value != this.firstName)
				{
					this.firstName = value;
					this.OnPropertyChanged("FirstName");
				}
			}
		}

		public string LastName
		{
			get
			{
				return this.lastName;
			}
			set
			{
				if (value != this.lastName)
				{
					this.lastName = value;
					this.OnPropertyChanged("LastName");
				}
			}
		}
		public User()
		{ }

		public User(string firstName, string lastName)
		{
			this.firstName = firstName;
			this.lastName = lastName;
		}

		
		public event PropertyChangedEventHandler PropertyChanged;

		protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
		{
			PropertyChangedEventHandler handler = this.PropertyChanged;
			if (handler != null)
			{
				handler(this, args);
			}
		}

		private void OnPropertyChanged(string propertyName)
		{
			this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
		}
	}
}